@@ -3,14 +3,15 @@ from io import BytesIO
 from pathlib import Path
 
 import httpx
-from codeboxapi import CodeBox
 from PIL import Image
 
-codebox = CodeBox(api_key="local")
+from codeboxapi import CodeBox
+
+codebox = CodeBox(api_key="sk-427ed7bc1c420490ef4bfa42369fa41d26e864")
 
 # download the iris dataset
 iris_csv_bytes = httpx.get(
-    "https://archive.ics.uci.edu/" "ml/machine-learning-databases/iris/iris.data"
+    "https://archive.ics.uci.edu/ml/machine-learning-databases/iris/iris.data"
 ).content
 
 # upload the dataset to the codebox
